@@ -1212,7 +1212,7 @@ def read(message, tag="", completion=None):
     out(
         MCC.up(2)
         + ACC.RESET
-        + MCC.erase_all_line
+        + MCC.ERASE_ALL_LINE
         + to_format(
             rea_pattern,
             {
